@@ -423,41 +423,8 @@ mxEvalByName <- function(name, model, compute=FALSE, show=FALSE, defvar.row = 1L
       list(x = as.symbol(name))))
 }
 
-mxBootstrapEval <- function(expression, model, defvar.row = 1L, ..., bq=c(.25,.75),
-			    method=c('bcbci','quantile')) {
-   if(!is(model, "MxModel")) {
-      stop("'model' argument must be a MxModel object")
-   }
-   method <- match.arg(method)
-  if (is.null(model$compute) || !is(model$compute, "MxComputeBootstrap")) {
-	  stop(paste("Compute plan", class(model$compute), "found in model",
-		     omxQuotes(model$name),
-		     "instead of MxComputeBootstrap. Have you run this model",
-		     "through mxBootstrap already?"))
-  }
-  cb <- model@compute
-  if (is.null(cb@output$raw)) {
-	  stop(paste("No bootstrap data foudn. Please run this model",
-		     "through mxBootstrap again."))
-  }
-  if (!is.na(cb@only)) {
-	  stop(paste("Detected mxBootstrap's only= option. Please mxBootstrap",
-		     "this model without using only="))
-  }
-  if (cb@output$numParam != length(coef(model))) {
-	  stop(paste("Model", omxQuotes(model), "has", length(coef(model)),
-		     "parameters but bootstrap data has", cb@output$numParam,
-		     "parameters. Please mxBootstrap this model again."))
-  }
-  raw <- cb@output$raw
-  mask <- raw[,'statusCode'] %in% cb@OK
-  bootData <- raw[mask, 3:(length(coef(model))+2), drop=FALSE]
-  if (sum(mask) < 3) {
-	  stop(paste("Less than 3 replications are available.",
-		     "Use mxBootstrap to increase the number of replications."))
-  }
-  expression <- match.call()$expression
-  modelvariable <- match.call()$model
+BootstrapEvalInternal <- function(expression, model, modelvariable, defvar.row, ...) {
+	bootData <- omxGetBootstrapReplications(model)
   mle <- cvectorize(EvalInternal(expression, model, modelvariable,
 				 compute=TRUE, show=FALSE, defvar.row, cache=new.env(parent = emptyenv()),
 						 cacheBack=FALSE, back=2L))
@@ -468,9 +435,29 @@ mxBootstrapEval <- function(expression, model, defvar.row = 1L, ..., bq=c(.25,.7
 						 compute=TRUE, show=FALSE, defvar.row, cache=new.env(parent = emptyenv()),
 						 cacheBack=FALSE, back=2L))
   }
+	list(mle=mle, result=result)
+}
 
-  cbind("SE"=apply(result, 2, sd),
-	summarizeBootstrap(mle, result, bq, method))
+omxBootstrapEval <- function(expression, model, defvar.row = 1L, ...) {
+  expression <- match.call()$expression
+  modelvariable <- match.call()$model
+  BootstrapEvalInternal(expression, model, modelvariable, defvar.row, ...)$result
+}
+
+omxBootstrapEvalCov <- function(expression, model, defvar.row = 1L, ...) {
+  expression <- match.call()$expression
+  modelvariable <- match.call()$model
+  cov(BootstrapEvalInternal(expression, model, modelvariable, defvar.row, ...)$result)
+}
+
+mxBootstrapEval <- function(expression, model, defvar.row = 1L, ..., bq=c(.25,.75),
+				method=c('bcbci','quantile')) {
+  expression <- match.call()$expression
+  modelvariable <- match.call()$model
+	method <- match.arg(method)
+  got <- BootstrapEvalInternal(expression, model, modelvariable, defvar.row, ...)
+	cbind("SE"=apply(got$result, 2, sd),
+	      summarizeBootstrap(got$mle, got$result, bq, method))
 }
 
 mxBootstrapEvalByName <- function(name, model, defvar.row=1L, ..., bq=c(.25,.75),
@@ -482,3 +469,12 @@ mxBootstrapEvalByName <- function(name, model, defvar.row=1L, ..., bq=c(.25,.75)
    eval(substitute(mxBootstrapEval(x, model, defvar.row, bq, method),
       list(x = as.symbol(name))))
 }
+
+omxBootstrapEvalByName <- function(name, model, defvar.row=1L, ...) {
+   if((length(name) != 1) || typeof(name) != "character") {
+      stop("'name' argument must be a character argument")
+   }
+   method <- match.arg(method)
+   eval(substitute(omxBootstrapEval(x, model, defvar.row),
+      list(x = as.symbol(name))))
+}
