@@ -583,7 +583,7 @@ print.summary.mxmodel <- function(x,...) {
 		cat("independent submodels time:", format(x$independentTime), '\n')
 		cat("cpu time:", format(x$cpuTime), '\n')
 	}
-	cat("Wall clock time (HH:MM:SS.hh):", format(.POSIXct(x$wallTime, tz="GMT"), "%H:%M:%OS2"), "\n")
+	cat("Wall clock time:", format(x$wallTime), "\n")
 	if (x$verbose==FALSE && !is.null(x$optimizerEngine)) {
 		cat("optimizer: ", x$optimizerEngine, '\n')
 	}
@@ -1084,6 +1084,10 @@ logLik.MxModel <- function(object, ...) {
 }
 mxStandardizeRAMpaths <- function(model, SE=FALSE, cov=NULL){
 	assertModelFreshlyRun(model)
+	
+	if(imxHasDefinitionVariable(model)){
+		warning("'model' (or one of its submodels) contains definition variables; interpret results of mxStandardizeRAMpaths() cautiously")
+	}
 
   #If SE=T,need to check for independent submodels because they will have their own Hessians;
   #recur main function as appropriate:
