@@ -385,8 +385,8 @@ suppressWarnings(omxCheckCloseEnough(modelOut[['test30d']]$result, A$values[0,0]
 omxCheckCloseEnough(modelOut[['test30e']]$result, mxEval(A[,], model), 0.001)
 omxCheckCloseEnough(modelOut[['test30f']]$result, mxEval(A[1,], model), 0.001)
 omxCheckCloseEnough(modelOut[['test30g']]$result, mxEval(A[,1], model), 0.001)
-suppressWarnings(omxCheckCloseEnough(modelOut[['test30h']]$result, as.matrix(A$values[0,]), 0.001))
-suppressWarnings(omxCheckCloseEnough(modelOut[['test30i']]$result, as.matrix(A$values[,0]), 0.001))
+omxCheckEquals(dim(modelOut[['test30h']]$result), c(0,0))
+omxCheckEquals(dim(modelOut[['test30i']]$result), c(0,0))
 omxCheckCloseEnough(modelOut[['test30j']]$result, mxEval(A[,1] + B[,2], model), 0.001)
 omxCheckCloseEnough(modelOut[['test30k']]$result, mxEval(A[1,] + B[2,], model), 0.001)
 omxCheckCloseEnough(modelOut[['test30l']]$result, A$values['a','v'], 0.001)
