@@ -56,10 +56,7 @@ static char sccsid[] = "@(#)merge.c	8.2 (Berkeley) 2/14/94";
 #include <stdlib.h>
 #include <string.h>
 #include "merge.h"
-
-#ifdef SHADOW_DIAG
-#pragma GCC diagnostic warning "-Wshadow"
-#endif
+#include "EnableWarnings.h"
 
 static void setup(unsigned char *, unsigned char *, size_t, size_t, mergesort_cmp_t, void *);
 static void insertionsort(unsigned char *, size_t, size_t, mergesort_cmp_t, void *);
